searchData={"items":[{"type":"module","title":"OrderedCollections","doc":"OrderedCollections provides sorted data structures for Elixir,\nincluding a `SortedMap` and a `SortedSet`.\n\nFor `SortedMap`, keys are maintained in a sorted order per Erlang's\n`:gb_trees` module.\n\nFor `SortedSet`, elements are maintained in a sorted order per Erlang's\n`:gb_sets` module.","ref":"OrderedCollections.html"},{"type":"module","title":"Modules - OrderedCollections","doc":"- `OrderedCollections.SortedMap` - A sorted key-value store implemented using Erlang's `:gb_trees`.\n  - `OrderedCollections.SortedSet` - A sorted set implemented using Erlang's `:gb_sets`.","ref":"OrderedCollections.html#module-modules"},{"type":"module","title":"Examples - OrderedCollections","doc":"iex> sm = OrderedCollections.SortedMap.new(%{b: 2, a: 1})\n    iex> OrderedCollections.SortedMap.get(sm, :a)\n    1\n\n    iex> ss = OrderedCollections.SortedSet.new([3, 1, 2])\n    iex> OrderedCollections.SortedSet.to_list(ss)\n    [1, 2, 3]\n\nYou can also use convenience functions:\n\n    iex> sm = OrderedCollections.new_map(%{x: 10})\n    iex> sm = OrderedCollections.put_map(sm, :y, 20)\n    iex> OrderedCollections.get_map(sm, :y)\n    20\n\n    iex> sm = OrderedCollections.new_map()\n    iex> sm = OrderedCollections.put_map(sm, :a, 1)\n    iex> OrderedCollections.to_map(sm)\n    %{a: 1}\n\n    iex> ss = OrderedCollections.new_set([3, 1, 2])\n    iex> ss = OrderedCollections.add_set_value(ss, 4)\n    iex> OrderedCollections.set_member?(ss, 4)\n    true\n\n    iex> ss = OrderedCollections.new_set()\n    iex> ss = OrderedCollections.add_set_value(ss, 1)\n    iex> OrderedCollections.SortedSet.to_list(ss)\n    [1]","ref":"OrderedCollections.html#module-examples"},{"type":"module","title":"Map Operations - OrderedCollections","doc":"The `SortedMap` module provides various operations:\n\n    iex> sm = OrderedCollections.new_map(%{b: 2, a: 1, c: 3})\n    iex> OrderedCollections.map_keys(sm)\n    [:a, :b, :c]\n    iex> OrderedCollections.map_values(sm)\n    [1, 2, 3]\n    iex> sm2 = OrderedCollections.new_map(%{b: 4, d: 5})\n    iex> OrderedCollections.map_merge(sm, sm2) |> OrderedCollections.to_map()\n    %{a: 1, b: 4, c: 3, d: 5}\n    iex> OrderedCollections.map_range(sm, :a, :b)\n    [a: 1, b: 2]\n    iex> OrderedCollections.map_min_key(sm)\n    :a\n    iex> OrderedCollections.map_max_key(sm)\n    :c","ref":"OrderedCollections.html#module-map-operations"},{"type":"module","title":"Set Operations - OrderedCollections","doc":"The `SortedSet` module also provides set operations:\n\n    iex> set1 = OrderedCollections.new_set([1, 2, 3])\n    iex> set2 = OrderedCollections.new_set([3, 4, 5])\n    iex> OrderedCollections.set_union(set1, set2) |> OrderedCollections.SortedSet.to_list()\n    [1, 2, 3, 4, 5]\n    iex> OrderedCollections.set_difference(set1, set2) |> OrderedCollections.SortedSet.to_list()\n    [1, 2]\n    iex> OrderedCollections.set_intersection(set1, set2) |> OrderedCollections.SortedSet.to_list()\n    [3]","ref":"OrderedCollections.html#module-set-operations"},{"type":"module","title":"Range Operations - OrderedCollections","doc":"You can get elements within a specific range:\n\n    iex> set = OrderedCollections.new_set([1, 2, 3, 4, 5])\n    iex> OrderedCollections.set_range(set, 2, 4) |> OrderedCollections.SortedSet.to_list()\n    [2, 3, 4]","ref":"OrderedCollections.html#module-range-operations"},{"type":"module","title":"Min/Max Operations - OrderedCollections","doc":"You can get the minimum and maximum elements:\n\n    iex> set = OrderedCollections.new_set([3, 1, 2])\n    iex> OrderedCollections.set_min(set)\n    1\n    iex> OrderedCollections.set_max(set)\n    3","ref":"OrderedCollections.html#module-min-max-operations"},{"type":"function","title":"OrderedCollections.add_set_value/2","doc":"Adds a value to the SortedSet.","ref":"OrderedCollections.html#add_set_value/2"},{"type":"function","title":"Examples - OrderedCollections.add_set_value/2","doc":"iex> ss = OrderedCollections.new_set([2, 3])\n    iex> ss = OrderedCollections.add_set_value(ss, 1)\n    iex> ss = OrderedCollections.add_set_value(ss, 3)\n    iex> OrderedCollections.SortedSet.to_list(ss)\n    [1, 2, 3]","ref":"OrderedCollections.html#add_set_value/2-examples"},{"type":"function","title":"OrderedCollections.delete_set_value/2","doc":"Deletes a value from the SortedSet.","ref":"OrderedCollections.html#delete_set_value/2"},{"type":"function","title":"Examples - OrderedCollections.delete_set_value/2","doc":"iex> ss = OrderedCollections.new_set([1, 2, 3])\n    iex> ss = OrderedCollections.delete_set_value(ss, 2)\n    iex> OrderedCollections.SortedSet.to_list(ss)\n    [1, 3]","ref":"OrderedCollections.html#delete_set_value/2-examples"},{"type":"function","title":"OrderedCollections.get_map/3","doc":"Retrieves the value for the given key from a SortedMap, returning a default if the key is missing.","ref":"OrderedCollections.html#get_map/3"},{"type":"function","title":"Examples - OrderedCollections.get_map/3","doc":"iex> sm = OrderedCollections.new_map(%{a: 1})\n  iex> OrderedCollections.get_map(sm, :a)\n  1\n  iex> OrderedCollections.get_map(sm, :b, 2)\n  2","ref":"OrderedCollections.html#get_map/3-examples"},{"type":"function","title":"OrderedCollections.map_delete/2","doc":"Deletes a key.","ref":"OrderedCollections.html#map_delete/2"},{"type":"function","title":"Examples - OrderedCollections.map_delete/2","doc":"iex> sm = OrderedCollections.new_map(%{a: 1, b: 2})\n    iex> sm2 = OrderedCollections.map_delete(sm, :b)\n    iex> OrderedCollections.map_has_key?(sm2, :b)\n    false","ref":"OrderedCollections.html#map_delete/2-examples"},{"type":"function","title":"OrderedCollections.map_has_key?/2","doc":"Checks if a key exists.","ref":"OrderedCollections.html#map_has_key?/2"},{"type":"function","title":"Examples - OrderedCollections.map_has_key?/2","doc":"iex> sm = OrderedCollections.new_map(%{a: 1, b: 2})\n    iex> OrderedCollections.map_has_key?(sm, :a)\n    true\n    iex> OrderedCollections.map_has_key?(sm, :c)\n    false","ref":"OrderedCollections.html#map_has_key?/2-examples"},{"type":"function","title":"OrderedCollections.map_keys/1","doc":"Returns the keys of the SortedMap in sorted order.","ref":"OrderedCollections.html#map_keys/1"},{"type":"function","title":"Examples - OrderedCollections.map_keys/1","doc":"iex> sm = OrderedCollections.new_map(%{b: 2, a: 1, c: 3})\n    iex> OrderedCollections.map_keys(sm)\n    [:a, :b, :c]","ref":"OrderedCollections.html#map_keys/1-examples"},{"type":"function","title":"OrderedCollections.map_max_key/1","doc":"Returns the largest key. Returns `:none` if the map is empty.","ref":"OrderedCollections.html#map_max_key/1"},{"type":"function","title":"Examples - OrderedCollections.map_max_key/1","doc":"iex> sm = OrderedCollections.new_map(%{b: 2, a: 1, c: 3})\n    iex> OrderedCollections.map_max_key(sm)\n    :c\n\n    iex> sm_empty = OrderedCollections.new_map()\n    iex> OrderedCollections.map_max_key(sm_empty)\n    :none","ref":"OrderedCollections.html#map_max_key/1-examples"},{"type":"function","title":"OrderedCollections.map_merge/2","doc":"Merges two SortedMaps. In case of duplicate keys, values from the second map override those from the first.","ref":"OrderedCollections.html#map_merge/2"},{"type":"function","title":"Examples - OrderedCollections.map_merge/2","doc":"iex> sm1 = OrderedCollections.new_map(%{a: 1, b: 2})\n    iex> sm2 = OrderedCollections.new_map(%{b: 3, c: 4})\n    iex> OrderedCollections.map_merge(sm1, sm2) |> OrderedCollections.to_map()\n    %{a: 1, b: 3, c: 4}","ref":"OrderedCollections.html#map_merge/2-examples"},{"type":"function","title":"OrderedCollections.map_min_key/1","doc":"Returns the smallest key. Returns `:none` if the map is empty.","ref":"OrderedCollections.html#map_min_key/1"},{"type":"function","title":"Examples - OrderedCollections.map_min_key/1","doc":"iex> sm = OrderedCollections.new_map(%{b: 2, a: 1, c: 3})\n    iex> OrderedCollections.map_min_key(sm)\n    :a\n\n    iex> sm_empty = OrderedCollections.new_map()\n    iex> OrderedCollections.map_min_key(sm_empty)\n    :none","ref":"OrderedCollections.html#map_min_key/1-examples"},{"type":"function","title":"OrderedCollections.map_range/3","doc":"Iterates over a range of keys, returning key-value pairs\nwhose keys are between `min` and `max` (inclusive).","ref":"OrderedCollections.html#map_range/3"},{"type":"function","title":"Examples - OrderedCollections.map_range/3","doc":"iex> sm = OrderedCollections.new_map(%{a: 1, b: 2, c: 3, d: 4})\n    iex> OrderedCollections.map_range(sm, :b, :c)\n    [b: 2, c: 3]","ref":"OrderedCollections.html#map_range/3-examples"},{"type":"function","title":"OrderedCollections.map_rebalance/1","doc":"Rebalances the tree.","ref":"OrderedCollections.html#map_rebalance/1"},{"type":"function","title":"Examples - OrderedCollections.map_rebalance/1","doc":"iex> sm = OrderedCollections.new_map(%{a: 1, b: 2, c: 3})\n    iex> smi = OrderedCollections.new_map() |> OrderedCollections.put_map(:a, 1) |> OrderedCollections.put_map(:b, 2) |> OrderedCollections.put_map(:c, 3)\n    iex> sm == smi\n    false\n    iex> OrderedCollections.map_rebalance(sm) == OrderedCollections.map_rebalance(smi)\n    true","ref":"OrderedCollections.html#map_rebalance/1-examples"},{"type":"function","title":"OrderedCollections.map_update/3","doc":"Updates a key with a function. If the key doesn't exist, it is set to `nil`.","ref":"OrderedCollections.html#map_update/3"},{"type":"function","title":"Examples - OrderedCollections.map_update/3","doc":"iex> sm = OrderedCollections.new_map(%{a: 1})\n    iex> sm = OrderedCollections.map_update(sm, :a, &(&1 + 1))\n    iex> OrderedCollections.get_map(sm, :a)\n    2\n\n    iex> OrderedCollections.new_map(%{a: 1}) |> OrderedCollections.map_update(:b, &(&1 + 1)) |> OrderedCollections.get_map(:b)\n    nil","ref":"OrderedCollections.html#map_update/3-examples"},{"type":"function","title":"OrderedCollections.map_update/4","doc":"Updates a key with a function. If the key doesn't exist, it sets it to `default`.","ref":"OrderedCollections.html#map_update/4"},{"type":"function","title":"Examples - OrderedCollections.map_update/4","doc":"iex> sm = OrderedCollections.new_map(%{a: 1})\n    iex> sm = OrderedCollections.map_update(sm, :a, &(&1 + 5), 0)\n    iex> OrderedCollections.get_map(sm, :a)\n    6\n\n    iex> OrderedCollections.new_map(%{a: 1}) |> OrderedCollections.map_update(:b, &(&1 + 1), 10) |> OrderedCollections.get_map(:b)\n    10","ref":"OrderedCollections.html#map_update/4-examples"},{"type":"function","title":"OrderedCollections.map_update_with_value/3","doc":"Replaces the value for `key` with `new_value` if the key exists.\nIf `key` does not exist, the map remains unchanged.","ref":"OrderedCollections.html#map_update_with_value/3"},{"type":"function","title":"Examples - OrderedCollections.map_update_with_value/3","doc":"iex> sm = OrderedCollections.new_map(%{a: 1, b: 2})\n    iex> sm = OrderedCollections.map_update_with_value(sm, :a, 100)\n    iex> OrderedCollections.get_map(sm, :a)\n    100\n    iex> OrderedCollections.map_update_with_value(sm, :c, 300)\n    iex> OrderedCollections.get_map(sm, :c)\n    nil","ref":"OrderedCollections.html#map_update_with_value/3-examples"},{"type":"function","title":"OrderedCollections.map_values/1","doc":"Returns the values of the SortedMap in the order corresponding to the sorted keys.","ref":"OrderedCollections.html#map_values/1"},{"type":"function","title":"Examples - OrderedCollections.map_values/1","doc":"iex> sm = OrderedCollections.new_map(%{b: 2, a: 1, c: 3})\n    iex> OrderedCollections.map_values(sm)\n    [1, 2, 3]","ref":"OrderedCollections.html#map_values/1-examples"},{"type":"function","title":"OrderedCollections.new_map/0","doc":"Creates a new empty SortedMap.","ref":"OrderedCollections.html#new_map/0"},{"type":"function","title":"Examples - OrderedCollections.new_map/0","doc":"iex> sm = OrderedCollections.new_map()\n  iex> OrderedCollections.to_map(sm)\n  %{}","ref":"OrderedCollections.html#new_map/0-examples"},{"type":"function","title":"OrderedCollections.new_map/1","doc":"Creates a new SortedMap from a regular map.","ref":"OrderedCollections.html#new_map/1"},{"type":"function","title":"Examples - OrderedCollections.new_map/1","doc":"iex> m = %{b: 2, a: 1}\n  iex> sm = OrderedCollections.new_map(m)\n  iex> OrderedCollections.get_map(sm, :a)\n  1","ref":"OrderedCollections.html#new_map/1-examples"},{"type":"function","title":"OrderedCollections.new_set/0","doc":"Creates a new empty SortedSet.","ref":"OrderedCollections.html#new_set/0"},{"type":"function","title":"Examples - OrderedCollections.new_set/0","doc":"iex> ss = OrderedCollections.new_set()\n    iex> OrderedCollections.SortedSet.to_list(ss)\n    []","ref":"OrderedCollections.html#new_set/0-examples"},{"type":"function","title":"OrderedCollections.new_set/1","doc":"Creates a new SortedSet from a list.","ref":"OrderedCollections.html#new_set/1"},{"type":"function","title":"Examples - OrderedCollections.new_set/1","doc":"iex> ss = OrderedCollections.new_set([3, 1, 2])\n    iex> OrderedCollections.SortedSet.to_list(ss)\n    [1, 2, 3]","ref":"OrderedCollections.html#new_set/1-examples"},{"type":"function","title":"OrderedCollections.put_map/3","doc":"Inserts a key-value pair into a SortedMap.","ref":"OrderedCollections.html#put_map/3"},{"type":"function","title":"Examples - OrderedCollections.put_map/3","doc":"iex> sm = OrderedCollections.new_map()\n  iex> sm = OrderedCollections.put_map(sm, :a, 1)\n  iex> OrderedCollections.get_map(sm, :a)\n  1","ref":"OrderedCollections.html#put_map/3-examples"},{"type":"function","title":"OrderedCollections.set_difference/2","doc":"Returns the difference between two SortedSets.","ref":"OrderedCollections.html#set_difference/2"},{"type":"function","title":"Examples - OrderedCollections.set_difference/2","doc":"iex> set1 = OrderedCollections.new_set([1, 2, 3])\n    iex> set2 = OrderedCollections.new_set([3, 4, 5])\n    iex> OrderedCollections.set_difference(set1, set2) |> OrderedCollections.SortedSet.to_list()\n    [1, 2]","ref":"OrderedCollections.html#set_difference/2-examples"},{"type":"function","title":"OrderedCollections.set_intersection/2","doc":"Returns the intersection of two SortedSets.","ref":"OrderedCollections.html#set_intersection/2"},{"type":"function","title":"Examples - OrderedCollections.set_intersection/2","doc":"iex> set1 = OrderedCollections.new_set([1, 2, 3])\n    iex> set2 = OrderedCollections.new_set([3, 4, 5])\n    iex> OrderedCollections.set_intersection(set1, set2) |> OrderedCollections.SortedSet.to_list()\n    [3]","ref":"OrderedCollections.html#set_intersection/2-examples"},{"type":"function","title":"OrderedCollections.set_max/1","doc":"Returns the maximum element of the SortedSet.","ref":"OrderedCollections.html#set_max/1"},{"type":"function","title":"Examples - OrderedCollections.set_max/1","doc":"iex> ss = OrderedCollections.new_set([3, 1, 2])\n    iex> OrderedCollections.set_max(ss)\n    3","ref":"OrderedCollections.html#set_max/1-examples"},{"type":"function","title":"OrderedCollections.set_member?/2","doc":"Checks if a value is a member of the SortedSet.","ref":"OrderedCollections.html#set_member?/2"},{"type":"function","title":"Examples - OrderedCollections.set_member?/2","doc":"iex> ss = OrderedCollections.new_set([1, 2, 3])\n    iex> OrderedCollections.set_member?(ss, 2)\n    true","ref":"OrderedCollections.html#set_member?/2-examples"},{"type":"function","title":"OrderedCollections.set_min/1","doc":"Returns the minimum element of the SortedSet.","ref":"OrderedCollections.html#set_min/1"},{"type":"function","title":"Examples - OrderedCollections.set_min/1","doc":"iex> ss = OrderedCollections.new_set([3, 1, 2])\n    iex> OrderedCollections.set_min(ss)\n    1","ref":"OrderedCollections.html#set_min/1-examples"},{"type":"function","title":"OrderedCollections.set_range/3","doc":"Returns elements within a given range (inclusive).","ref":"OrderedCollections.html#set_range/3"},{"type":"function","title":"Examples - OrderedCollections.set_range/3","doc":"iex> ss = OrderedCollections.new_set([1, 2, 3, 4, 5])\n    iex> OrderedCollections.set_range(ss, 2, 4) |> OrderedCollections.SortedSet.to_list()\n    [2, 3, 4]","ref":"OrderedCollections.html#set_range/3-examples"},{"type":"function","title":"OrderedCollections.set_union/2","doc":"Returns the union of two SortedSets.","ref":"OrderedCollections.html#set_union/2"},{"type":"function","title":"Examples - OrderedCollections.set_union/2","doc":"iex> set1 = OrderedCollections.new_set([1, 2, 3])\n    iex> set2 = OrderedCollections.new_set([3, 4, 5])\n    iex> OrderedCollections.set_union(set1, set2) |> OrderedCollections.SortedSet.to_list()\n    [1, 2, 3, 4, 5]","ref":"OrderedCollections.html#set_union/2-examples"},{"type":"function","title":"OrderedCollections.to_map/1","doc":"Creates a map from a SortedMap.","ref":"OrderedCollections.html#to_map/1"},{"type":"function","title":"Examples - OrderedCollections.to_map/1","doc":"iex> sm = OrderedCollections.new_map(%{b: 2, a: 1})\n  iex> OrderedCollections.to_map(sm)\n  %{a: 1, b: 2}","ref":"OrderedCollections.html#to_map/1-examples"},{"type":"module","title":"OrderedCollections.SortedMap","doc":"A sorted key-value store implemented using Erlang's `:gb_trees` (Red-Black Trees).\n\nThis module stores items in sorted order by their keys and offers a rich set of features that allow it to integrate seamlessly with Elixir’s core protocols:\n\n- **Enumerable:**\n  SortedMap implements the Enumerable protocol. This means you can use all the standard functions in the `Enum` module (like `Enum.map/2`, `Enum.reduce/3`, and `Enum.slice/2`) directly on a SortedMap.\n\n  **Example:**\n\n      iex> map = SortedMap.new(%{b: 2, a: 1, c: 3})\n      iex> Enum.map(map, fn {k, v} -> {k, v * 2} end)\n      [a: 2, b: 4, c: 6]\n\n- **Collectable:**\n  SortedMap implements the Collectable protocol, allowing you to build a SortedMap from any enumerable using `Enum.into/2`.\n\n  **Example:**\n\n      iex> map = Enum.into([{:a, 1}, {:b, 2}], SortedMap.new())\n      iex> SortedMap.to_list(map)\n      [a: 1, b: 2]\n\n- **Inspect:**\n  SortedMap implements the Inspect protocol, providing a clean and concise representation when you use `IO.inspect/1`.\n\n  **Example:**\n      iex> map = SortedMap.new(%{b: 2, a: 1})\n      iex> captured = ExUnit.CaptureIO.capture_io(fn -> IO.inspect(map) end)\n      iex> captured\n      ~s(#SortedMap<%{a: 1, b: 2}>\\n)\n\n\n- **JSON Encoding:**\n  SortedMap implements the JSON.Encoder protocol (using the native JSON support in Elixir 1.18 and later). This ensures that when you encode a SortedMap to JSON, the keys appear in sorted order.\n\n  **Example:**\n\n      iex> map = SortedMap.new(%{a: 1, b: 2})\n      iex> JSON.encode!(map)\n      ~s({\"a\":1,\"b\":2})","ref":"OrderedCollections.SortedMap.html"},{"type":"module","title":"Implementation Details - OrderedCollections.SortedMap","doc":"Internally, SortedMap wraps Erlang's `:gb_trees` to achieve efficient insertion, lookup, and deletion operations while automatically maintaining the order of keys. By leveraging the power of Erlang's native data structures and integrating with protocols like Enumerable, Collectable, Inspect, and JSON.Encoder, SortedMap behaves like a first-class Elixir collection with a familiar API.","ref":"OrderedCollections.SortedMap.html#module-implementation-details"},{"type":"function","title":"OrderedCollections.SortedMap.delete/2","doc":"Deletes a key.","ref":"OrderedCollections.SortedMap.html#delete/2"},{"type":"function","title":"Examples - OrderedCollections.SortedMap.delete/2","doc":"iex> sm = SortedMap.new(%{a: 1, b: 2})\n    iex> sm2 = SortedMap.delete(sm, :b)\n    iex> SortedMap.has_key?(sm2, :b)\n    false","ref":"OrderedCollections.SortedMap.html#delete/2-examples"},{"type":"function","title":"OrderedCollections.SortedMap.get/3","doc":"Retrieves a value by key, returning a default if missing.","ref":"OrderedCollections.SortedMap.html#get/3"},{"type":"function","title":"Examples - OrderedCollections.SortedMap.get/3","doc":"iex> sm = SortedMap.new(%{a: 1})\n    iex> SortedMap.get(sm, :a)\n    1\n    iex> SortedMap.get(sm, :b, :default)\n    :default","ref":"OrderedCollections.SortedMap.html#get/3-examples"},{"type":"function","title":"OrderedCollections.SortedMap.has_key?/2","doc":"Checks if a key exists.","ref":"OrderedCollections.SortedMap.html#has_key?/2"},{"type":"function","title":"Examples - OrderedCollections.SortedMap.has_key?/2","doc":"iex> sm = SortedMap.new(%{a: 1, b: 2})\n    iex> SortedMap.has_key?(sm, :a)\n    true\n    iex> SortedMap.has_key?(sm, :c)\n    false","ref":"OrderedCollections.SortedMap.html#has_key?/2-examples"},{"type":"function","title":"OrderedCollections.SortedMap.keys/1","doc":"Returns the keys of the SortedMap in sorted order.","ref":"OrderedCollections.SortedMap.html#keys/1"},{"type":"function","title":"Examples - OrderedCollections.SortedMap.keys/1","doc":"iex> sm = SortedMap.new(%{b: 2, a: 1, c: 3})\n    iex> SortedMap.keys(sm)\n    [:a, :b, :c]","ref":"OrderedCollections.SortedMap.html#keys/1-examples"},{"type":"function","title":"OrderedCollections.SortedMap.max_key/1","doc":"Returns the largest key. Returns `:none` if the map is empty.","ref":"OrderedCollections.SortedMap.html#max_key/1"},{"type":"function","title":"Examples - OrderedCollections.SortedMap.max_key/1","doc":"iex> sm = SortedMap.new(%{b: 2, a: 1, c: 3})\n    iex> SortedMap.max_key(sm)\n    :c\n\n    iex> sm = SortedMap.new(%{b: 10, a: 99, c: 3})\n    iex> SortedMap.max_key(sm)\n    :c\n\n    iex> sm_empty = SortedMap.new()\n    iex> SortedMap.max_key(sm_empty)\n    :none","ref":"OrderedCollections.SortedMap.html#max_key/1-examples"},{"type":"function","title":"OrderedCollections.SortedMap.merge/2","doc":"Merges two SortedMaps. In case of duplicate keys, values from the second map override those from the first.","ref":"OrderedCollections.SortedMap.html#merge/2"},{"type":"function","title":"Examples - OrderedCollections.SortedMap.merge/2","doc":"iex> sm1 = SortedMap.new(%{a: 1, b: 2})\n    iex> sm2 = SortedMap.new(%{b: 3, c: 4})\n    iex> SortedMap.merge(sm1, sm2) |> SortedMap.to_list()\n    [{:a, 1}, {:b, 3}, {:c, 4}]","ref":"OrderedCollections.SortedMap.html#merge/2-examples"},{"type":"function","title":"OrderedCollections.SortedMap.min_key/1","doc":"Returns the smallest key. Returns `:none` if the map is empty.","ref":"OrderedCollections.SortedMap.html#min_key/1"},{"type":"function","title":"Examples - OrderedCollections.SortedMap.min_key/1","doc":"iex> sm = SortedMap.new(%{b: 2, a: 1, c: 3})\n    iex> SortedMap.min_key(sm)\n    :a\n\n    iex> sm_empty = SortedMap.new()\n    iex> SortedMap.min_key(sm_empty)\n    :none","ref":"OrderedCollections.SortedMap.html#min_key/1-examples"},{"type":"function","title":"OrderedCollections.SortedMap.new/0","doc":"Creates a new empty sorted map.","ref":"OrderedCollections.SortedMap.html#new/0"},{"type":"function","title":"Examples - OrderedCollections.SortedMap.new/0","doc":"iex> sm = SortedMap.new()\n    iex> SortedMap.to_map(sm)\n    %{}","ref":"OrderedCollections.SortedMap.html#new/0-examples"},{"type":"function","title":"OrderedCollections.SortedMap.new/1","doc":"Creates a new sorted map from a standard map.","ref":"OrderedCollections.SortedMap.html#new/1"},{"type":"function","title":"Examples - OrderedCollections.SortedMap.new/1","doc":"iex> sm = SortedMap.new(%{a: 1, b: 2})\n    iex> SortedMap.get(sm, :a)\n    1\n    iex> SortedMap.get(sm, :b)\n    2","ref":"OrderedCollections.SortedMap.html#new/1-examples"},{"type":"type","title":"OrderedCollections.SortedMap.non_empty_t/0","doc":"","ref":"OrderedCollections.SortedMap.html#t:non_empty_t/0"},{"type":"type","title":"OrderedCollections.SortedMap.non_empty_tree/0","doc":"","ref":"OrderedCollections.SortedMap.html#t:non_empty_tree/0"},{"type":"function","title":"OrderedCollections.SortedMap.put/3","doc":"Inserts a key-value pair, maintaining order.","ref":"OrderedCollections.SortedMap.html#put/3"},{"type":"function","title":"Examples - OrderedCollections.SortedMap.put/3","doc":"iex> sm = SortedMap.new(%{a: 1})\n    iex> sm = SortedMap.put(sm, :b, 2)\n    iex> SortedMap.get(sm, :b)\n    2","ref":"OrderedCollections.SortedMap.html#put/3-examples"},{"type":"function","title":"OrderedCollections.SortedMap.range/3","doc":"Iterates over a range of keys, returning key-value pairs\nwhose keys are between `min` and `max` (inclusive).","ref":"OrderedCollections.SortedMap.html#range/3"},{"type":"function","title":"Examples - OrderedCollections.SortedMap.range/3","doc":"iex> sm = SortedMap.new(%{a: 1, b: 2, c: 3, d: 4})\n    iex> SortedMap.range(sm, :b, :c)\n    [{:b, 2}, {:c, 3}]","ref":"OrderedCollections.SortedMap.html#range/3-examples"},{"type":"function","title":"OrderedCollections.SortedMap.rebalance/1","doc":"Rebalances the tree.","ref":"OrderedCollections.SortedMap.html#rebalance/1"},{"type":"function","title":"Examples - OrderedCollections.SortedMap.rebalance/1","doc":"iex> sm = SortedMap.new(%{a: 1, b: 2, c: 3})\niex> smi = SortedMap.new() |> SortedMap.put(:a, 1) |> SortedMap.put(:b, 2) |> SortedMap.put(:c, 3)\niex> sm == smi\nfalse\niex> sm |> SortedMap.rebalance() == smi |> SortedMap.rebalance()\ntrue","ref":"OrderedCollections.SortedMap.html#rebalance/1-examples"},{"type":"type","title":"OrderedCollections.SortedMap.t/0","doc":"","ref":"OrderedCollections.SortedMap.html#t:t/0"},{"type":"function","title":"OrderedCollections.SortedMap.to_list/1","doc":"Returns all key-value pairs in sorted order.","ref":"OrderedCollections.SortedMap.html#to_list/1"},{"type":"function","title":"Examples - OrderedCollections.SortedMap.to_list/1","doc":"iex> sm = SortedMap.new(%{b: 2, a: 1})\n    iex> SortedMap.to_list(sm)\n    [{:a, 1}, {:b, 2}]","ref":"OrderedCollections.SortedMap.html#to_list/1-examples"},{"type":"function","title":"OrderedCollections.SortedMap.to_map/1","doc":"Converts the `SortedMap` into a standard `Map`, losing the sorted property.","ref":"OrderedCollections.SortedMap.html#to_map/1"},{"type":"function","title":"Examples - OrderedCollections.SortedMap.to_map/1","doc":"iex> sm = SortedMap.new(%{b: 2, a: 1})\n    iex> SortedMap.to_map(sm)\n    %{a: 1, b: 2}\n\n    iex> sm = SortedMap.new(%{a: 2, b: 1})\n    iex> captured = ExUnit.CaptureIO.capture_io(fn -> IO.inspect(sm) end)\n    iex> captured\n    ~s(#SortedMap<%{a: 2, b: 1}>\\n)\n    iex> SortedMap.to_map(sm)\n    %{a: 2, b: 1}","ref":"OrderedCollections.SortedMap.html#to_map/1-examples"},{"type":"function","title":"OrderedCollections.SortedMap.update/3","doc":"Updates a key with a function. If the key doesn’t exist,\nit is set to `nil`.","ref":"OrderedCollections.SortedMap.html#update/3"},{"type":"function","title":"Examples - OrderedCollections.SortedMap.update/3","doc":"iex> sm = SortedMap.new(%{a: 1})\n    iex> sm = SortedMap.update(sm, :a, &(&1 + 1))\n    iex> SortedMap.get(sm, :a)\n    2\n\n    iex> SortedMap.new(%{a: 1}) |> SortedMap.update(:b, &(&1 + 1)) |> SortedMap.get(:b)\n    nil","ref":"OrderedCollections.SortedMap.html#update/3-examples"},{"type":"function","title":"OrderedCollections.SortedMap.update/4","doc":"Updates a key with a function. If the key doesn’t exist,\nit sets it to `default`.","ref":"OrderedCollections.SortedMap.html#update/4"},{"type":"function","title":"Examples - OrderedCollections.SortedMap.update/4","doc":"iex> sm = SortedMap.new(%{a: 1})\n    iex> sm = SortedMap.update(sm, :a, &(&1 + 5), 0)\n    iex> SortedMap.get(sm, :a)\n    6\n\n    iex> SortedMap.new(%{a: 1}) |> SortedMap.update(:b, &(&1 + 1), 10) |> SortedMap.get(:b)\n    10","ref":"OrderedCollections.SortedMap.html#update/4-examples"},{"type":"function","title":"OrderedCollections.SortedMap.update_with_value/3","doc":"Replaces the value for `key` with `new_value` if the key exists.\nIf `key` does not exist, the map remains unchanged.","ref":"OrderedCollections.SortedMap.html#update_with_value/3"},{"type":"function","title":"Examples - OrderedCollections.SortedMap.update_with_value/3","doc":"iex> sm = SortedMap.new(%{a: 1, b: 2})\n    iex> sm = SortedMap.update_with_value(sm, :a, 100)\n    iex> SortedMap.get(sm, :a)\n    100\n    iex> SortedMap.update_with_value(sm, :c, 300)\n    iex> SortedMap.get(sm, :c)\n    nil","ref":"OrderedCollections.SortedMap.html#update_with_value/3-examples"},{"type":"function","title":"OrderedCollections.SortedMap.values/1","doc":"Returns the values of the SortedMap in the order corresponding to the sorted keys.","ref":"OrderedCollections.SortedMap.html#values/1"},{"type":"function","title":"Examples - OrderedCollections.SortedMap.values/1","doc":"iex> sm = SortedMap.new(%{b: 2, a: 1, c: 3})\n    iex> SortedMap.values(sm)\n    [1, 2, 3]","ref":"OrderedCollections.SortedMap.html#values/1-examples"},{"type":"module","title":"OrderedCollections.SortedSet","doc":"A sorted set implemented using Erlang's `:gb_sets`.\n\nThis module provides a sorted set data structure that stores unique elements in sorted order.\nInternally, it wraps Erlang's `:gb_sets` to provide efficient operations (insertion, deletion, and\nmembership checking). SortedSet is designed to integrate seamlessly with Elixir's core protocols,\nmaking it behave like a first-class Elixir collection.","ref":"OrderedCollections.SortedSet.html"},{"type":"module","title":"Protocol Support - OrderedCollections.SortedSet","doc":"- **Enumerable:**\n  SortedSet implements the Enumerable protocol. This means you can traverse the set using functions\n  like `Enum.map/2`, `Enum.reduce/3`, and `Enum.slice/2`, all while preserving the sorted order of elements.\n\n  **Example:**\n      iex> set = SortedSet.new([3, 1, 2])\n      iex> Enum.map(set, &(&1 * 2))\n      [2, 4, 6]\n\n- **Collectable:**\n  SortedSet implements the Collectable protocol, allowing you to build a SortedSet from any enumerable\n  using `Enum.into/2`.\n\n  **Example:**\n      iex> set = Enum.into([3, 1, 2], SortedSet.new())\n      iex> SortedSet.to_list(set)\n      [1, 2, 3]\n\n- **Inspect:**\n  SortedSet implements the Inspect protocol, providing a clean and readable output when you use\n  `IO.inspect/1`.\n\n  **Example:**\n      iex> set = SortedSet.new([3, 1, 2])\n      iex> captured = ExUnit.CaptureIO.capture_io(fn -> IO.inspect(set) end)\n      iex> captured\n      ~s(#SortedSet<[1, 2, 3]>\\n)\n\n- **JSON Encoding:**\n  SortedSet implements the JSON.Encoder protocol (using Elixir 1.18's native JSON support) so that\n  when you encode a SortedSet to JSON, it is represented as an array with the elements in sorted order.\n\n  **Example:**\n      iex> set = SortedSet.new([3, 1, 2])\n      iex> JSON.encode!(set)\n      \"[1,2,3]\"","ref":"OrderedCollections.SortedSet.html#module-protocol-support"},{"type":"module","title":"Implementation Details - OrderedCollections.SortedSet","doc":"Internally, SortedSet leverages Erlang's `:gb_sets` to maintain a sorted collection of unique elements.\nBy integrating with Enumerable, Collectable, Inspect, and JSON.Encoder, SortedSet provides a natural,\nidiomatic API that behaves just like other Elixir collections while preserving the sorted order of its elements.","ref":"OrderedCollections.SortedSet.html#module-implementation-details"},{"type":"function","title":"OrderedCollections.SortedSet.add/2","doc":"Adds a value to the SortedSet.\n\nReturns the set unchanged if the item already exists in the set","ref":"OrderedCollections.SortedSet.html#add/2"},{"type":"function","title":"Examples - OrderedCollections.SortedSet.add/2","doc":"iex> set = OrderedCollections.SortedSet.new([2, 3])\n    iex> set = OrderedCollections.SortedSet.add(set, 1)\n    iex> set = OrderedCollections.SortedSet.add(set, 3)\n    iex> OrderedCollections.SortedSet.to_list(set)\n    [1, 2, 3]","ref":"OrderedCollections.SortedSet.html#add/2-examples"},{"type":"function","title":"OrderedCollections.SortedSet.delete/2","doc":"Deletes a value from the SortedSet.","ref":"OrderedCollections.SortedSet.html#delete/2"},{"type":"function","title":"Examples - OrderedCollections.SortedSet.delete/2","doc":"iex> set = OrderedCollections.SortedSet.new([1, 2, 3])\n    iex> set = OrderedCollections.SortedSet.delete(set, 2)\n    iex> OrderedCollections.SortedSet.to_list(set)\n    [1, 3]","ref":"OrderedCollections.SortedSet.html#delete/2-examples"},{"type":"function","title":"OrderedCollections.SortedSet.difference/2","doc":"Returns a new SortedSet that contains elements in the first set that are not present in the second.","ref":"OrderedCollections.SortedSet.html#difference/2"},{"type":"function","title":"Examples - OrderedCollections.SortedSet.difference/2","doc":"iex> set1 = OrderedCollections.SortedSet.new([1, 2, 3, 4, 5])\n    iex> set2 = OrderedCollections.SortedSet.new([2, 4])\n    iex> OrderedCollections.SortedSet.difference(set1, set2) |> OrderedCollections.SortedSet.to_list()\n    [1, 3, 5]","ref":"OrderedCollections.SortedSet.html#difference/2-examples"},{"type":"type","title":"OrderedCollections.SortedSet.element/0","doc":"","ref":"OrderedCollections.SortedSet.html#t:element/0"},{"type":"function","title":"OrderedCollections.SortedSet.fold/3","doc":"Folds over the elements of a SortedSet in sorted order.","ref":"OrderedCollections.SortedSet.html#fold/3"},{"type":"function","title":"Examples - OrderedCollections.SortedSet.fold/3","doc":"iex> set = OrderedCollections.SortedSet.new([1, 2, 3])\n    iex> OrderedCollections.SortedSet.fold(set, 0, &+/2)\n    6","ref":"OrderedCollections.SortedSet.html#fold/3-examples"},{"type":"function","title":"OrderedCollections.SortedSet.intersection/2","doc":"Returns a new SortedSet that contains elements present in both sets.","ref":"OrderedCollections.SortedSet.html#intersection/2"},{"type":"function","title":"Examples - OrderedCollections.SortedSet.intersection/2","doc":"iex> set1 = SortedSet.new([1, 2, 3])\n    iex> set2 = SortedSet.new([2, 3, 4])\n    iex> SortedSet.intersection(set1, set2) |> SortedSet.to_list()\n    [2, 3]","ref":"OrderedCollections.SortedSet.html#intersection/2-examples"},{"type":"function","title":"OrderedCollections.SortedSet.max/1","doc":"Returns the maximum element of the SortedSet.","ref":"OrderedCollections.SortedSet.html#max/1"},{"type":"function","title":"Examples - OrderedCollections.SortedSet.max/1","doc":"iex> set = OrderedCollections.SortedSet.new([3, 1, 2])\n    iex> OrderedCollections.SortedSet.max(set)\n    3","ref":"OrderedCollections.SortedSet.html#max/1-examples"},{"type":"function","title":"OrderedCollections.SortedSet.member?/2","doc":"Checks if a value is a member of the SortedSet.","ref":"OrderedCollections.SortedSet.html#member?/2"},{"type":"function","title":"Examples - OrderedCollections.SortedSet.member?/2","doc":"iex> set = OrderedCollections.SortedSet.new([1, 2, 3])\n    iex> OrderedCollections.SortedSet.member?(set, 2)\n    true\n    iex> OrderedCollections.SortedSet.member?(set, 4)\n    false","ref":"OrderedCollections.SortedSet.html#member?/2-examples"},{"type":"function","title":"OrderedCollections.SortedSet.min/1","doc":"Returns the minimum element of the SortedSet.","ref":"OrderedCollections.SortedSet.html#min/1"},{"type":"function","title":"Examples - OrderedCollections.SortedSet.min/1","doc":"iex> set = OrderedCollections.SortedSet.new([3, 1, 2])\n    iex> OrderedCollections.SortedSet.min(set)\n    1","ref":"OrderedCollections.SortedSet.html#min/1-examples"},{"type":"function","title":"OrderedCollections.SortedSet.new/0","doc":"Creates a new empty SortedSet.","ref":"OrderedCollections.SortedSet.html#new/0"},{"type":"function","title":"Examples - OrderedCollections.SortedSet.new/0","doc":"iex> set = OrderedCollections.SortedSet.new()\n    iex> OrderedCollections.SortedSet.to_list(set)\n    []","ref":"OrderedCollections.SortedSet.html#new/0-examples"},{"type":"function","title":"OrderedCollections.SortedSet.new/1","doc":"Creates a new SortedSet from a list.","ref":"OrderedCollections.SortedSet.html#new/1"},{"type":"function","title":"Examples - OrderedCollections.SortedSet.new/1","doc":"iex> set = OrderedCollections.SortedSet.new([3, 1, 2])\n    iex> OrderedCollections.SortedSet.to_list(set)\n    [1, 2, 3]","ref":"OrderedCollections.SortedSet.html#new/1-examples"},{"type":"type","title":"OrderedCollections.SortedSet.non_empty_set/0","doc":"","ref":"OrderedCollections.SortedSet.html#t:non_empty_set/0"},{"type":"type","title":"OrderedCollections.SortedSet.non_empty_t/0","doc":"","ref":"OrderedCollections.SortedSet.html#t:non_empty_t/0"},{"type":"function","title":"OrderedCollections.SortedSet.range/3","doc":"Returns a list of elements in the SortedSet that fall within the given range (inclusive).","ref":"OrderedCollections.SortedSet.html#range/3"},{"type":"function","title":"Examples - OrderedCollections.SortedSet.range/3","doc":"iex> set = OrderedCollections.SortedSet.new([1, 2, 3, 4, 5])\n    iex> OrderedCollections.SortedSet.range(set, 2, 4) |> OrderedCollections.SortedSet.to_list()\n    [2, 3, 4]","ref":"OrderedCollections.SortedSet.html#range/3-examples"},{"type":"opaque","title":"OrderedCollections.SortedSet.t/0","doc":"","ref":"OrderedCollections.SortedSet.html#t:t/0"},{"type":"function","title":"OrderedCollections.SortedSet.to_list/1","doc":"Converts the SortedSet into a list of elements in sorted order.","ref":"OrderedCollections.SortedSet.html#to_list/1"},{"type":"function","title":"Examples - OrderedCollections.SortedSet.to_list/1","doc":"iex> set = OrderedCollections.SortedSet.new([3, 1, 2])\n    iex> OrderedCollections.SortedSet.to_list(set)\n    [1, 2, 3]","ref":"OrderedCollections.SortedSet.html#to_list/1-examples"},{"type":"function","title":"OrderedCollections.SortedSet.union/2","doc":"Returns a new SortedSet that is the union of two SortedSets.","ref":"OrderedCollections.SortedSet.html#union/2"},{"type":"function","title":"Examples - OrderedCollections.SortedSet.union/2","doc":"iex> set1 = OrderedCollections.SortedSet.new([1, 3, 5])\n    iex> set2 = OrderedCollections.SortedSet.new([2, 3, 4])\n    iex> OrderedCollections.SortedSet.union(set1, set2) |> OrderedCollections.SortedSet.to_list()\n    [1, 2, 3, 4, 5]","ref":"OrderedCollections.SortedSet.html#union/2-examples"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}